@@ -17,17 +17,21 @@ class ActionResolver(object):
 
     def _resolve_variation(self, action, experiment):
         variation = experiment.get_variation_by_id_or_none(action.variation_id)
-        if not variation:
+        if variation is None:
             raise Exception('variation[{}]'.format(action.variation_id))
         return variation
 
     def _resolve_bucket(self, action, workspace, experiment, user):
         bucket = workspace.get_bucket_or_none(action.bucket_id)
-        if not bucket:
+        if bucket is None:
             raise Exception('bucket[{}]'.format(action.bucket_id))
 
-        allocated_slot = self.bucketer.bucketing(bucket, user)
-        if not allocated_slot:
+        identifier = user.identifiers.get(experiment.identifier_type)
+        if identifier is None:
+            return None
+
+        allocated_slot = self.bucketer.bucketing(bucket, identifier)
+        if allocated_slot is None:
             return None
 
         return experiment.get_variation_by_id_or_none(allocated_slot.variation_id)
