@@ -1,5 +1,6 @@
 import json
 import logging
+import time
 from json import JSONEncoder
 
 import requests
@@ -28,6 +29,7 @@ class EventDispatcher(object):
         request_headers = {enums.Default.SDK_KEY_HEADER: sdk_key,
                            enums.Default.SDK_NAME_HEADER: 'python-sdk',
                            enums.Default.SDK_VERSION_HEADER: version.__version__,
+                           enums.Default.SDK_TIME_HEADER: str(round(time.time() * 1000)),
                            enums.Default.CONTENT_TYPE_HEADER: enums.Default.SDK_CONTENT_TYPE}
 
         try:
