@@ -5,8 +5,9 @@ from datetime import timedelta
 from six.moves import queue
 
 from hackle import logger as _logging
+from hackle.commons import utils
 from hackle.event.event_dispatcher import EventDispatcher
-from hackle.event.user_event import (UserEvent, ExposureEvent, TrackEvent)
+from hackle.event.user_event import (UserEvent, ExposureEvent, TrackEvent, RemoteConfigEvent)
 
 
 class BatchEventProcessor(object):
@@ -117,15 +118,20 @@ class BatchEventProcessor(object):
 
         exposure_events = []
         track_events = []
+        remote_config_events = []
         for event in to_process_batch:
             if isinstance(event, ExposureEvent):
                 exposure_events.append(event)
             if isinstance(event, TrackEvent):
                 track_events.append(event)
+            if isinstance(event, RemoteConfigEvent):
+                event.properties = utils.filter_properties(event.properties)
+                remote_config_events.append(event)
 
         events = {
             'exposureEvents': exposure_events,
-            'trackEvents': track_events
+            'trackEvents': track_events,
+            'remoteConfigEvents': remote_config_events
         }
 
         try:
